@@ -17,7 +17,7 @@ Utilities for documenting functions, classes and methods.
 #
 #  This program is distributed in the hope that it will be useful,
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 #  GNU Lesser General Public License for more details.
 #
 #  You should have received a copy of the GNU Lesser General Public License
@@ -28,12 +28,12 @@ Utilities for documenting functions, classes and methods.
 
 # stdlib
 import builtins
-import platform
 from inspect import cleandoc
 from types import MethodType
 from typing import Any, Callable, Dict, Optional, Sequence, Type, TypeVar, Union
 
 # this package
+from domdf_python_tools.compat import PYPY
 from domdf_python_tools.typing import MethodDescriptorType, MethodWrapperType, WrapperDescriptorType
 
 __all__ = [
@@ -49,7 +49,6 @@ __all__ = [
 		]
 
 F = TypeVar('F', bound=Callable[..., Any])
-PYPY = platform.python_implementation() == "PyPy"
 
 
 def deindent_string(string: Optional[str]) -> str:
@@ -148,8 +147,14 @@ def make_sphinx_links(input_string: str, builtins_list: Optional[Sequence[str]]
 
 	working_string = f"{input_string}"
 
-	for builtin in {x for x in builtins_list if not x.startswith("__") and x != "None"}:
-		working_string = working_string.replace(f"``{builtin}``", f":class:`{builtin}`")
+	for builtin in builtins_list:
+		if builtin.startswith("__"):
+			continue
+
+		if builtin in {"None", "False", "None"}:
+			working_string = working_string.replace(f"``{builtin}``", f":py:obj:`{builtin}`")
+		else:
+			working_string = working_string.replace(f"``{builtin}``", f":class:`{builtin}`")
 
 	return working_string
 
@@ -307,15 +312,13 @@ new_return_types = {
 
 def _do_prettify(obj: Type, base: Type, new_docstrings: Dict[str, str]):
 	"""
-	Perform the actual prettification for :func`~.prettify_docstrings`.
+	Perform the actual prettifying for :func`~.prettify_docstrings`.
+
+	.. versionadded:: 0.8.0
 
 	:param obj:
 	:param base:
 	:param new_docstrings:
-
-	:rtype:
-
-	.. versionadded:: 0.8.0
 	"""
 
 	for attr_name in new_docstrings:
@@ -349,11 +352,9 @@ def prettify_docstrings(obj: Type) -> Type:
 	"""
 	Decorator to prettify the default :class:`object` docstrings for use in Sphinx documentation.
 
-	:param obj: The object to prettify the method docstrings for.
-
-	:rtype:
-
 	.. versionadded:: 0.8.0
+
+	:param obj: The object to prettify the method docstrings for.
 	"""
 
 	repr_docstring = f"Return a string representation of the :class:`~{obj.__module__}.{obj.__name__}`."
